"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeScriptErrorHandler = void 0;
const common_1 = require("@typescript-nameof/common");
/**
 * Provides the functionality to report errors to a TypeScript compiler.
 *
 * @template TFeatures
 * The type of the features for the error handler.
 */
class TypeScriptErrorHandler extends common_1.ErrorHandler {
    /**
     * Initializes a new instance of the {@linkcode TypeScriptErrorHandler}.
     *
     * @param features
     * A set of features for the error handler.
     */
    constructor(features) {
        super();
        this.features = features;
    }
    /**
     * Gets a set of features for the error handler.
     */
    get Features() {
        return this.features;
    }
    /**
     * Reports the specified {@linkcode error}.
     *
     * @param location
     * The location of the specified {@linkcode node}.
     *
     * @param item
     * The item related to the specified {@linkcode error}.
     *
     * @param context
     * The context of the operation.
     *
     * @param error
     * The error to report.
     */
    Report(location, item, context, error) {
        this.ReportDiagnostic(location, item, context, this.GetDiagnostic(item, context, error), error);
    }
    /**
     * Creates a diagnostic for the specified {@linkcode error}.
     *
     * @param node
     * The node related to the error.
     *
     * @param context
     * The context of the operation.
     *
     * @param error
     * The error to create a diagnostic for.
     *
     * @returns
     * The diagnostic for the specified {@linkcode error}.
     */
    GetDiagnostic(node, context, error) {
        return Object.assign({ category: this.Features.TypeScript.DiagnosticCategory.Error, source: "typescript-nameof", messageText: error.message, code: 1337 }, (context.file ?
            {
                file: context.file,
                start: node.getStart(context.file),
                length: node.getWidth(context.file)
            } :
            {
                file: undefined,
                start: undefined,
                length: undefined
            }));
    }
    /**
     * Reports the specified {@linkcode diagnostic}.
     *
     * @param location
     * The location of the specified {@linkcode node}.
     *
     * @param item
     * The node related to the error.
     *
     * @param context
     * The context of the operation.
     *
     * @param diagnostic
     * The diagnostic to report.
     *
     * @param error
     * The original error.
     */
    ReportDiagnostic(location, item, context, diagnostic, error) {
        super.Report(location, item, context, error);
    }
}
exports.TypeScriptErrorHandler = TypeScriptErrorHandler;
//# sourceMappingURL=TypeScriptErrorHandler.cjs.map